"A very simple short module containing useful functions"


What's new in version 1.6.1-> Corrected some color values

What's new in version 1.7.1-> Added transform_color function and updated documentation.